# Default Configuration for Microsoft Build Engine

!include <win32.mak>

CC = cl
LINKER = link
AR = lib
CP = copy
MV = move
RM = del

CFLAGS = $(cflags) $(MTFLAGS) -w -I ../include $(MPIFLAGS)
LDFLAGS = $(conlflags) $(MTLDFLAGS) $(CMPILIB) $(FMPILIB)


# Define the following macros if necessary.

#OPENMP = defined
#INTEL = defined
#FORTRAN = defined
#MPI = defined
#AMG = defined


# Configuration for OpenMP 

!ifdef OPENMP
MTFLAGS = $(cvarsmt) -MT -openmp 
MTLDFLAGS = $(conlibsmt) 
!else
MTFLAGS = $(cvars) -MD
MTLDFLAGS = $(conlibs) 
!endif


# Configuration for Intel Compiler 

!ifdef INTEL

CC = icl

!ifdef OPENMP
MTFLAGS = $(cvarsmt) -MT -Qopenmp -Qopenmp-lib:compat 
!endif
CFLAGS = -O3 $(cflags) $(MTFLAGS) \
       -Qansi_alias -w -I ../include \
       -DHAVE_CONFIG_WIN32_H $(FORTRANFLAG) $(MPIFLAGS) $(AMGFLAG) 

!ifdef FORTRAN
FC = ifort
FORTRANFLAG = -DUSE_FORTRAN
!ifdef OPENMP
MTFLAGS = -MT -Qopenmp -Qopenmp-lib:compat 
!else
MTFLAGS = -MD 
!endif
!endif
FFLAGS = -c -O3 -fpp -DZERO_ORIGIN=1 $(MTFLAGS) \
       -Qansi_alias -w -I ../include $(MPIFLAGS)
!endif 


# Configuration for MPICH

!ifdef MPI 
MPIDIR = "C:\Program Files\MPICH2"
MPIFLAGS = -DUSE_MPI -I $(MPIDIR)\include
CMPILIB = $(MPIDIR)\lib\mpi.lib 
FMPILIB = $(MPIDIR)\lib\fmpich2.lib
!endif


# Configuration for AMG (parallel version is still buggy)

!ifdef AMG
AMGDIR = ..\src\fortran\amg
AMGFLAG = -DUSE_SAAMG
!endif



!ifndef FORTRAN
all: libs exes_test exes_etest exes_spmvtest
!else
all: libs exes_test exes_etest exes_spmvtest \
     libs_lisf_init exes_testf exes_etestf
!endif
	$(CP) test1.exe lsolve.exe
	$(CP) etest5.exe esolve.exe

!ifndef AMG
libs: objs_esolver objs_fortran objs_matrix objs_matvec objs_precision \
      objs_precon objs_solver objs_system objs_vector
!else
libs: objs_esolver objs_fortran objs_matrix objs_matvec objs_precision \
      objs_precon objs_solver objs_system objs_vector objs_saamg 
!endif
	$(AR) *.obj -out:lis.lib

objs_esolver: ..\src\esolver\*.obj 
objs_fortran: ..\src\fortran\*.obj 
objs_matrix: ..\src\matrix\*.obj 
objs_matvec: ..\src\matvec\*.obj 
objs_precision: ..\src\precision\*.obj 
objs_precon: ..\src\precon\*.obj 
objs_solver: ..\src\solver\*.obj 
objs_system: ..\src\system\*.obj 
objs_vector: ..\src\vector\*.obj

!ifndef MPI
objs_saamg: $(AMGDIR)\lis_s_data_type_AMGCG.obj \
	    $(AMGDIR)\lis_s_queue.obj \
	    $(AMGDIR)\lis_s_aggregate.obj \
	    $(AMGDIR)\lis_s_sort.obj \
	    $(AMGDIR)\lis_s_data_creation_AMGCG.obj \
	    $(AMGDIR)\lis_s_solver_AMGCG.obj \
	    $(AMGDIR)\lis_s_finit.obj
	    
!else
objs_saamg: $(AMGDIR)\lis_m_data_type_AMGCG.obj \
	    $(AMGDIR)\lis_m_queue.obj \
	    $(AMGDIR)\lis_m_hash.obj \
	    $(AMGDIR)\lis_m_solver_Gnum.obj \
	    $(AMGDIR)\lis_m_solver_SR2.obj \
	    $(AMGDIR)\lis_m_aggregate.obj \
	    $(AMGDIR)\lis_m_count_time_mod.obj \
	    $(AMGDIR)\lis_m_sort.obj \
	    $(AMGDIR)\lis_m_data_creation_AMGCG.obj \
	    $(AMGDIR)\lis_m_solver_AMGCG.obj \
	    $(AMGDIR)\lis_m_finit.obj 
!endif

exes_test: test1.exe test2.exe test3.exe test4.exe test5.exe test6.exe
exes_etest: etest1.exe etest2.exe etest3.exe etest4.exe etest5.exe etest6.exe
exes_spmvtest: spmvtest1.exe spmvtest2.exe spmvtest3.exe spmvtest4.exe spmvtest5.exe

exes_testf: test1f.exe test4f.exe
exes_etestf: etest1f.exe etest4f.exe

test1.exe: ..\test\$*.obj
test2.exe: ..\test\$*.obj
test3.exe: ..\test\$*.obj
test4.exe: ..\test\$*.obj
test5.exe: ..\test\$*.obj
test6.exe: ..\test\$*.obj
etest1.exe: ..\test\$*.obj
etest2.exe: ..\test\$*.obj
etest3.exe: ..\test\$*.obj
etest4.exe: ..\test\$*.obj
etest5.exe: ..\test\$*.obj
etest6.exe: ..\test\$*.obj
spmvtest1.exe: ..\test\$*.obj
spmvtest2.exe: ..\test\$*.obj
spmvtest3.exe: ..\test\$*.obj
spmvtest4.exe: ..\test\$*.obj
spmvtest5.exe: ..\test\$*.obj

libs_lisf_init:
	$(FC) $(FFLAGS) -out:lisf_init.obj ..\src\fortran\lisf_init.f lis.lib

test1f.exe: ..\test\$*.obj
	$(LINKER) $(LDFLAGS) $*.obj lisf_init.obj lis.lib

test4f.exe: ..\test\$*.obj
	$(LINKER) $(LDFLAGS) $*.obj lisf_init.obj lis.lib

etest1f.exe: ..\test\$*.obj
	$(LINKER) $(LDFLAGS) $*.obj lisf_init.obj lis.lib

etest4f.exe: ..\test\$*.obj
	$(LINKER) $(LDFLAGS) $*.obj lisf_init.obj lis.lib 

.c.obj:
	$(CC) $(CFLAGS) $*.c

.f.obj:
	$(FC) $(FFLAGS) $*.f 

.f90.obj:
	$(FC) $(FFLAGS) $*.f90

.obj.exe:
	$(LINKER) $(LDFLAGS) $*.obj lis.lib 

clean:
	$(RM) *.obj *.mod *.pdb

cleanall: 
	$(RM) *.lib *.mod *.exe *.obj *.pdb
